==> haskell-prettyprinter-ansi-terminal-1.1.1.2-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.1.2
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.1.2-Hn6AF2e23pvFksm5BKvUCk
key:                  prettyprinter-ansi-terminal-1.1.1.2-Hn6AF2e23pvFksm5BKvUCk
license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  373559747ea24a9c3c1723aa2ebd735a
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-8.8.1/site-local/prettyprinter-ansi-terminal-1.1.1.2

library-dirs:
    /usr/lib/ghc-8.8.1/site-local/prettyprinter-ansi-terminal-1.1.1.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.1/prettyprinter-ansi-terminal-1.1.1.2

hs-libraries:
    HSprettyprinter-ansi-terminal-1.1.1.2-Hn6AF2e23pvFksm5BKvUCk

depends:
    ansi-terminal-0.10.3-9zJT3Osp5wTAaMBIHKdPu2 base-4.13.0.0
    prettyprinter-1.3.0-ApEaLw1GGx2Aer4v0JC6aK text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.1.2
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.1.2-4zkEblsrWKNtJdkDZdcah
key:                  prettyprinter-ansi-terminal-1.1.1.2-4zkEblsrWKNtJdkDZdcah
license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  42d9fd11bdc46a5e7985daa779c742fc
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-8.8.3/site-local/prettyprinter-ansi-terminal-1.1.1.2

library-dirs:
    /usr/lib/ghc-8.8.3/site-local/prettyprinter-ansi-terminal-1.1.1.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/prettyprinter-ansi-terminal-1.1.1.2

hs-libraries:         HSprettyprinter-ansi-terminal-1.1.1.2-4zkEblsrWKNtJdkDZdcah
depends:
    ansi-terminal-0.10.3-2mLj4sTjIwVaqOtXn4TV8 base-4.13.0.0
    prettyprinter-1.5.0-EYbhRR8P27MLxzBVqwtqjc text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
